@@ -1,5 +1,5 @@
 /* npth.h - a lightweight implementation of pth over pthread.
- *          Configured for: armv7a-unknown-linux-musleabihf.
+ *          Configured for: mips64-unknown-linux-gnuabi64.
  * Copyright (C) 2011, 2012, 2015, 2017, 2024 g10 Code GmbH
  *
  * This file is part of nPth.
@@ -222,7 +222,7 @@ int npth_mutex_timedlock(npth_mutex_t *mutex, const struct timespec *abstime);
 
 #define npth_mutex_unlock pthread_mutex_unlock
 
-#if 1
+#if defined(__USE_UNIX98) || defined(__USE_XOPEN2K)
 #ifdef _NPTH_NO_RWLOCK
 
 typedef int npth_rwlockattr_t;
